@@ -3,7 +3,7 @@ Agnocomplete Widgets
 """
 from django.forms import widgets
 from django.urls import reverse_lazy
-from django.utils.encoding import force_text as text
+from django.utils.encoding import force_str as text
 from django.conf import settings
 
 
